pub struct EventId(pub Uuid);Expand description
Stable identifier for an auditable operational event.
Use this id to correlate the source fact, workflow decision, review gate, and resulting staff or customer action without inventing undocumented authority after the fact.
Tuple Fields
0: UuidTrait Implementations
Sourceimpl<'de> Deserialize<'de> for EventId
impl<'de> Deserialize<'de> for EventId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for EventId
impl Ord for EventId
Sourceimpl PartialOrd for EventId
impl PartialOrd for EventId
impl Copy for EventId
impl Eq for EventId
impl StructuralPartialEq for EventId